# bfqry

[![PyPI - Version](https://img.shields.io/pypi/v/bfqry.svg)](https://pypi.org/project/bfqry)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/bfqry.svg)](https://pypi.org/project/bfqry)

-----

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install bfqry
```

## Dependencies

- [argcomplete](https://pypi.org/project/argcomplete/)
- [openpyxl](https://pypi.org/project/openpyxl/)
- [pybatfish](https://pypi.org/project/pybatfish/)
- [requests](https://pypi.org/project/requests/)
- [setuptools](https://pypi.org/project/setuptools/)

## License

`bfqry` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
